@@ -8,12 +8,21 @@ use Amazon::SQS::Simple::Base; # for constants
 use Amazon::SQS::Simple::Queue;
 use base qw(Exporter Amazon::SQS::Simple::Base);
 
-our $VERSION   = '2.02';
+our $VERSION   = '2.04';
 our @EXPORT_OK = qw( timestamp );
 
 sub GetQueue {
     my ($self, $queue_endpoint) = @_;
-    return new Amazon::SQS::Simple::Queue(
+
+	if ($queue_endpoint =~ /^arn:aws:sqs/) {
+		my ($host, $user, $queue);
+		(undef, undef, undef, $host, $user, $queue) = split(/:/, $queue_endpoint);
+		$queue_endpoint = "https://sqs.$host.amazonaws.com/$user/$queue";
+	}
+
+    return Amazon::SQS::Simple::Queue->new(
+        $self->{AWSAccessKeyId},	#AWSAccessKeyId and SecretKey are the first two arguments to Amazon::SQS::Simple::Base->new
+        $self->{SecretKey},
         %$self,
         Endpoint => $queue_endpoint,
     );
@@ -29,6 +38,8 @@ sub CreateQueue {
     
     if ($href->{CreateQueueResult}{QueueUrl}) {
         return Amazon::SQS::Simple::Queue->new(
+            $self->{AWSAccessKeyId},	#AWSAccessKeyId and SecretKey are the first two arguments to Amazon::SQS::Simple::Base->new
+            $self->{SecretKey},
             %$self,
             Endpoint => $href->{CreateQueueResult}{QueueUrl},
         );
@@ -45,7 +56,9 @@ sub ListQueues {
     # default to the current version
     if ($href->{ListQueuesResult}{QueueUrl}) {
         my @result = map {
-            new Amazon::SQS::Simple::Queue(
+            Amazon::SQS::Simple::Queue->new(
+                $self->{AWSAccessKeyId},	#AWSAccessKeyId and SecretKey are the first two arguments to Amazon::SQS::Simple::Base->new
+                $self->{SecretKey},
                 %$self,
                 Endpoint => $_,
             )        
@@ -242,7 +255,7 @@ in release 0.9.
 James Neal provided the proxy support code in release 2.0
 Roland Walker provided support for the newer signature version in release 2.0
 Chris Jones provied the batch message code in release 2.0
-
+Glenn Fowler (among others) provided a patch for the subtle access bug surfaved by hash key randomisation, as well as some test cleanup code in 2.04
 =head1 AUTHOR
 
 Copyright 2007-2008 Simon Whitaker E<lt>swhitaker@cpan.orgE<gt>
